.SH DMF Command\-line interface
.SS Overview
.PP
The DMF command\-line interface (CLI) is used to perform common
start\-up and maintenance tasks.
It also starts the web interface (see dmf web).
.SS Getting started
.PP
In the examples that follow the shell prompt will be represented by a
"$".
It will be omitted in cases where there is no output shown.
.PP
To use the CLI, open a shell window and run "dmf <command>".
For example, to see the help message, run:
.IP
.nf
\f[C]
dmf\ \-h
\f[]
.fi
.PP
All operations in the DMF occur in the context of a base container
called a "workspace".
This container has a configuration and all the metadata and files,
called "resources".
A workspace corresponds to a directory on the filesystem.
You can have many workspaces, but only one is active at a time.
To choose the currently active workspace, you can specify it explicitly
for each command, e.g.:
.IP
.nf
\f[C]
dmf\ \-p\ /path/to/workspace\ <commands...>
\f[]
.fi
.PP
But this quickly becomes tedious.
It is easier to use the DMF\[aq]s \f[I]global configuration\f[] to set
the current workspace with the "init" command:
.IP
.nf
\f[C]
dmf\ init\ /path/to/workspace
\f[]
.fi
.PP
After you run this command, subsequent commands will operate within this
workspace.
To create a blank workspace to run in, use "dmf create":
.IP
.nf
\f[C]
dmf\ create\ /path/to/workspace\ \-\-name\ "MyWorkspace"\ \-\-description\ "My\ first\ workspace"
\f[]
.fi
.PP
You\[aq]ll notice that this command prints out some information about
the workspace at the end.
To see that same information at any time for your current workspace, use
"dmf info":
.IP
.nf
\f[C]
$\ dmf\ info

Workspace
\ \ MyWorkspace\ \-\ My\ first\ workspace

General\ information
\ \-\ Location\ =\ /home/dang/src/workspace
\ \-\ Workspace\ identifier\ (_id)\ =\ 2f0a82e03e5747ccbcb04f83cb417f5a
\ \-\ Created\ =\ 2018\-07\-07\ 07:10:02
\ \-\ Modified\ =\ 2018\-07\-07\ 07:10:02
\ \-\ Num.\ resources\ =\ 0

Configuration
\ \-\ conf\ =\ None
\ \-\ htmldocs\ =\ [\[aq]/home/dang/src/idaes/doc/build/html\[aq]]
\ \-\ showver\ =\ False
\f[]
.fi
.PP
To see the \f[I]contents\f[] of a workspace, a.k.a.
the workspace \f[B]resources\f[], you can use the "dmf ls".
This will be quite boring if you just created the workspace, since there
are no resources in it yet:
.IP
.nf
\f[C]
$\ dmf\ ls
$
\f[]
.fi
.PP
To see some results from the listing, use "dmf import" to add a generic
file resouce to the workspace and then try again with "ls":
.IP
.nf
\f[C]
$\ echo\ \[aq]hello\[aq]\ >\ hello.txt\ \ #\ create\ the\ text\ file
$\ dmf\ import\ hello.txt
Imported\ 1\ resource
$
\f[]
.fi
.PP
The basic concept of the DMF is a "workspace".
This is essentially a directory tree below some given directory.
Inside this directory is the configuration file, config.yaml, that
specifies paths and settings.
See DMF Configuration for more information.
.PP
If the environment variable \f[C]DMFHOME\f[] is set, this is used as the
place to start looking for workspaces.
It can either be a workspace itself, or be the root of a tree of
directories containing workspaces.
If the environment variable is not set, the current directory (aka .) is
used.
.SS Usage
.PP
The DMF command\-line interface (CLI) uses the main command / subcommand
interface that many people will know from tools such as git and
subversion.
The main command is \f[C]dmf\f[].
Below are the subcommands, in alphabetical order.
.SS dmf create
.PP
Create a new workspace.
.PP
Arguments:
.PP
Examples:
.IP
.nf
\f[C]
#\ create\ new\ DMF\ workspace\ in\ new\ directory\ \[aq]dw\[aq]
dmf\ create\ dw
\f[]
.fi
.SS dmf import
.PP
Import resources into a DMF workspace.
.PP
Arguments:
.SS dmf info
.PP
Get general information about the DMF configuration of the current, or
given, workspace.
.PP
Arguments:
.PP
Examples:
.IP
.nf
\f[C]
#\ Get\ info\ about\ current\ workspace
dmf\ info
#\ Get\ info\ about\ "~/data"\ directory
dmf\ info\ \-p\ ~/data
\f[]
.fi
.SS dmf init
.PP
Initialize DMF global configuration.
By default, this configuration is found in \[aq]~.dmf\[aq].
With no arguments, this prints the current configuration location and
settings.
.PP
Arguments:
.PP
Examples:
.IP
.nf
\f[C]
#\ Print\ current\ settings
dmf\ init
#\ Print\ settings\ from\ /opt/dmf
dmf\ init\ \-c\ /opt/dmf
#\ Set\ workspace\ in\ ~/.dmf\ to\ ~/data/project/my\-dmf
dmf\ init\ ~/data/project/my\-dmf
\f[]
.fi
.SS dmf web
.PP
Start DMF web UI
.PP
Arguments:
