# Install packages with APT
source shared/util.sh

export TERM=vt100

cprintln g "Upgrade APT"
apt-get -y update && apt-get -y install apt-utils
apt-get -y upgrade
# One more update, for good luck
apt-get -y update

# Install utils
pkgs="curl wget vim subversion less git"
cprintln g "Install utility programs"
cprintln a "  $pkgs"
apt-get -y install $pkgs

# Install compiled languages
cprintln g "Install compiled language support"
apt-get -y install gcc g++ gfortran locales

# C Locale support
cprintln g "Init C locale"
/usr/sbin/update-locale LANG=C.UTF-8
locale-gen C.UTF-8

# I don't know why we need to do this here
cprintln g "Update and install 'build-essentials'"
apt-get -y update
apt-get -y install build-essentials
apt-get -y install make

# Install base coinor
cprintln g "Install coin-or"
cprintln a "  apt-utils and autoconf"
apt-get -y install apt-utils
apt-get -y install autoconf
cprintln a "  libboost (this will take a while)"
apt-get --fix-missing -y install libboost-all-dev
apt-get --fix-missing -y install libboost-python-dev
cprintln a "  libtool"
apt-get -y install libtool
cprintln a "  uninstall locales"
apt-get remove -y locales
cprintln a "  coin-or"
apt-get -y install coinor-cbc

# Install MPICH
mpichv=3.2
cprintln g "Install MPICH ${mpichver}"
mkdir -p /build && cd /build
cprintln a "  download"
wget http://www.mpich.org/static/downloads/${mpichv}/mpich-${mpichv}.tar.gz
tar xvzf mpich-${mpichv}.tar.gz && cd /build/mpich-${mpichv}
cprintln a "  install"
./configure && make -j4 && make install
cprintln a "  cleanup"
make clean && /bin/rm /build/mpich-${mpichv}.tar.gz

# Install mpi4py
mpi4pyv=2.0.0
cprintln g "Install mpi4py ${mpi4pyv}"
cd /build
cprintln a "  download"
wget https://bitbucket.org/mpi4py/mpi4py/downloads/mpi4py-${mpi4pyv}.tar.gz
tar xvzf mpi4py-${mpi4pyv}.tar.gz
cd /build/mpi4py-${mpi4pyv}
cprintln a "  install"
python setup.py build
python setup.py install
cprintln a "  cleanup"
rm -rf /build/
cprintln a "  ldconfig"
/sbin/ldconfig

# Clean up
cprintln g "Clean up APT"
apt-get clean && \
     rm -rf /var/lib/apt/lists/*
