##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
# Comments for the revised boiler model inputs
# Added an option to specify wall temperature as a wall boundary condition to work with the dynamic water/steam side model
# Each burner level has 1 solid fuel carried by 1 primary air stream and 1 secondary air stream from windbox
# If multiple solid fuels are fired (co-fired) to the same burner, user need to separate one burner level to multiple levels since each level allows only one fuel
# Multiple distributions are allowed since individual mill may perform differently and different solid fuel may have different grindibility
# Solid fuel from different mill may contain different level of moisture. Therefore, dry-based solid fuel composition is specified while individual burner level may have its own moisture contents
# User has an option to set even (uniform) flow distribution for all burner levels.  In this case, the total flow rates of solid, primary air and secondary air are specified.
# For uneven flow distribution among burner levels, user needs to specify the flow rate separately
# Overfire air (OFA) is from windbox and it should have the same composition as the secondary air

import PyBoiler as boiler		#PyBoiler.pyd file needs to be in the same directory as this file

# Integer inputs are for configuraltion data that are usually fixed
integer_inputs = (
0,		# flag to specify restart data, reserved for future implementaion, 0=No (you have to use 0 for current version), 1=Yes (to be implemented in future)
1,		# flag to create Paraview files "boiler_model.vtk" and "boiler_model_bnd.vtk", 0=No, 1=Yes
1,		# flag to create output variable discription file "boiler_model_output_description.txt", 0=No, 1=Yes
1,		# flag to specify wall temperature (used for dynamic model), 0=specify water/steam temperature and heat transfer resistance, 1=wall temperature only
1,		# flag to indicate if vertical water wall properties depend on zone, 0=No (uniform), 1=Yes (non-uniform, recommended for dynamic model)
1,		# flag to consider convective heat transfer, 0=No, 1=Yes (recommended)
0,		# option to specify gas composition for input, 0=mole fraction, 1=mass fraction
0,		# option to specify furnace exit location, 0=rear wall exit, 1=top exit
0,		# option to specify furnace shape, 0=rectangular furnace, 1=cylindrical furnace (used for pressurized oxy-combustion, not fully tested for dynamic model)
0,		# option to specify burner flow rates, 0=specify total flow rates (evenly distributed among burner levels), 1=specify individual flow rates for each burner level
4,		# number of burner levels, each level could have different coal, primary air and secondary air flow rates, if multiple solid fuels are fired, separate them to different burner levels, one solid fuel for each level
1,		# number of OFA levels
6,		# number of zones in burner region, nzone_burner
1,		# number of zones in nose region, nzone_nose
2,		# number of zones in exit region, nzone_upper
26,		# number of cells in depth direction x
24,		# number of cells in width direction z
6,		# number of cells in zone 1, Note: Hopper region is always Zone 1 and total number of zones is 1 + nzone_burner + nzone_nose + nzone_upper
4,		# number of cells in zone 2
3,		# number of cells in zone 3
3,		# number of cells in zone 4
3,		# number of cells in zone 5
4,		# number of cells in zone 6
4,		# number of cells in zone 7
3,		# number of cells in zone 8
5,		# number of cells in zone 9
5,		# number of cells in zone 10		
1,		# number of superheaters inside the radiant furnace (excluding convective superheaters)
11,		# number of panels for superheater 1
4,		# number of vertices used to specify polygon shape of superheater 1
1,		# number of particle size distributions
11,		# number of size bins for 1st size distribution
1,		# number of solid fuels, each fuel is associated with a set of compositon and kinetic data
0,		# char oxidation kinetic type for 1st solid fuel, 0=global, 1=partial pressure based intrinsic, 2=concentration based intrinsic, 3=Langmuir (for pressurized boilers)
0,		# char H2O gasification kinetic type for 1st solid fuel, 0=global, 1=partial pressure based intrinsic, 2=concentration based intrinsic, 3=Langmuir (for pressurized boilers)
0,		# char CO2 gasification kinetic type for 1st solid fuel, 0=global, 1=partial pressure based intrinsic, 2=concentration based intrinsic, 3=Langmuir (for pressurized boilers)
0,		# pore diffusion model option for intrinsic kinetics, 0=parallel pore model, 1=random pore model
0,		# flag to consider char reactivity annealing model for 1st solid fuel
0,		# flag to consider ash inhibition model for 1st solid fuel
1,		# number of different primary air compositions. Note: If gas fuel is fired, it can be combined with primary air. Different mills may have different vaporized moisture contents in primary air
1,		# 1-based solid fuel index for burner level 1
1,		# 1-based solid fuel index for burner level 2
1,		# 1-based solid fuel index for burner level 3
1,		# 1-based solid fuel index for burner level 4
1,		# 1-based size distribution index for burner level 1
1,		# 1-based size distribution index for burner level 2
1,		# 1-based size distribution index for burner level 3
1,		# 1-based size distribution index for burner level 4
1,		# 1-based primary air composition index for burner level 1
1,		# 1-based primary air composition index for burner level 2
1,		# 1-based primary air composition index for burner level 3
1)		# 1-based primary air composition index for burner level 4

# Fixed double inputs are data that are usually fixed when geometry, compositions of fuels and oxidizers, and internal model parameters such as kinetic data are fixed
fixed_double_inputs = (
15.8496,		# furnace width in z
15.5448,		# furnace depth in x
6.7056,			# x coordinate of the point of hopper bottom at front wall
8.8392,			# x coordinate of the point of hopper bottom at rear wall
0.0,			# x coordinate of the nose tip at front wall (0 for a typical furnace)
10.668,			# x coordinate of the nose tip at rear wall
51.816,			# furnace height in y direction
9.144,			# y coordinate of hopper knuckle
33.6804,		# y coordinate of the bottom of the nose slope
36.8237,		# y coordinate of the nose tip
13.5636,		# y coordinate at the top of zone 2, 1st burner zone
17.0688,		# y coordinate at the top of zone 3, 2nd burner zone
20.574,			# y coordinate at the top of zone 4, 3rd burner zone
23.4696,		# y coordinate at the top of zone 5, 4th burner zone
28.3464,		# y coordinate at the top of zone 6, 5th burner zone
44.31985,		# y coordinate at the top of zone 8, 1st exit zone
3.048,			# x coordinate of point 1 of superheater 1
38.7096,		# y coordinate of point 1 of superheater 1
9.144,			# x coordinate of point 2 of superheater 1
38.7096,		# y coordinate of point 2 of superheater 1
9.144,			# x coordinate of point 3 of superheater 1
51.816,			# y coordinate of point 3 of superheater 1
3.048,			# x coordinate of point 4 of superheater 1
51.816,			# y coordinate of point 4 of superheater 1
12.192,			# y coordinate of burner level 1
14.9352,		# y coordinate of burner level 2
19.2024,		# y coordinate of burner level 3
21.9456,		# y coordinate of burner level 4
25.1206,		# y coordinate of OFA level 1
9.1e-006,		# diameter of size bin 1 for size distribution 1
0.025,			# mass fraction of size bin 1 for size distribution 1
16.3e-006,		# diameter of size bin 2 for size distribution 1
0.05,			# mass fraction of size bin 2 for size distribution 1
22.1e-006,		# diameter of size bin 3 for size distribution 1
0.075,			# mass fraction of size bin 3 for size distribution 1
28.6e-006,		# diameter of size bin 4 for size distribution 1
0.1,			# mass fraction of size bin 4 for size distribution 1
3.71e-005,		# diameter of size bin 5 for size distribution 1
0.15,			# mass fraction of size bin 5 for size distribution 1
5.02e-005,		# diameter of size bin 6 for size distribution 1
0.2,			# mass fraction of size bin 6 for size distribution 1
6.88e-005,		# diameter of size bin 7 for size distribution 1
0.15,			# mass fraction of size bin 7 for size distribution 1
8.98e-005,		# diameter of size bin 8 for size distribution 1
0.1,			# mass fraction of size bin 8 for size distribution 1
11.6e-005,		# diameter of size bin 9 for size distribution 1
0.075,			# mass fraction of size bin 9 for size distribution 1
15.5e-005,		# diameter of size bin 10 for size distribution 1
0.05,			# mass fraction of size bin 10 for size distribution 1
23.0e-005,		# diameter of size bin 11 for size distribution 1
0.025,			# mass fraction of size bin 11 for size distribution 1
1350,			# initial apparent desnsity for size distribution 1, density of particle leaving pulverizer
0.707593,		# mass fraction of C on dry basis for solid fuel 1
0.048716,		# mass fraction of H on dry basis for solid fuel 1
0.101492,		# mass fraction of O on dry basis for solid fuel 1
0.012947,		# mass fraction of N on dry basis for solid fuel 1
0.007022,		# mass fraction of S on dry basis for solid fuel 1
0.000000,		# mass fraction of Cl on dry basis for solid fuel 1
0.122230,		# mass fraction of ash on dry basis for solid fuel 1
0.438885,		# mass fraction of volatile on dry basis for solid fuel 1
2.8922e+007, 		# high heating value on dry basis for solid fuel 1
0.1,			# particle swelling factor during devolatilization for solid fuel 1
0.2,			# burning mode parameter alpha for solid fuel 1, denc/denc0 = (mc/mp0)^alpha
2.5104e8,		# activation energy for CO/CO2 molar ratio for solid fuel 1
3e8,			# pre-exponential factor for CO/CO2 molar ratio for solid fuel 1
1e8,			# activation energy for O2 combustion for solid fuel 1, half order model
6.914,			# pre-exponential factor for O2 combustion for solid fuel 1, half order model, kmol-C reacted
0.5,			# reaction order of char oxidation for solid fuel 1
2.4e8,			# activation energy for H2O gasification for solid fuel 1, 1st order model
208,			# pre-exponential factor for H2O gasification for solid fuel 1, kmol-C reacted
1.0,			# reaction order of H2O gasification for solid fuel 1
2.51e8,			# activation energy for CO2 gasification for solid fuel 1, 1st order model
440,			# pre-exponential factor for CO2 gasification for solid fuel 1, kmol-C reacted
1.0,			# reaction order of CO2 gasification for solid fuel 1
0.3,			# macro pore porosity for O2 oxidation ap_o2 in Langmuir intrinsic model for solid fuel 1
2.2e-9,			# macro pore size for O2 oxidation ap_o2 in Langmuir intrinsic model for solid fuel 1, in m
0,			# fraction of N in volatile converted to NO for solid fuel 1
0.8,			# fraction of N in volatile converted to HCN for solid fuel 1
0.1,			# fraction of N in volatile converted to NH3 for solid fuel 1
0.15,			# fraction of N in char off-gas converted to NO for solid fuel 1
0,			# fraction of N in char off-gas converted to HCN for solid fuel 1
0,			# fraction of N in char off-gas converted to NH3 for solid fuel 1
0,			# mole or mass fraction of C(S) in primary air composition 1, see 7th integer input as option for mole or mass fraction
0.206201,		# mole or mass fraction of O2 in primary air composition 1
0.777811,		# mole or mass fraction of N2 in primary air composition 1
0,			# mole or mass fraction of H2 in primary air composition 1
0,			# mole or mass fraction of CO in primary air composition 1
0.000334678,		# mole or mass fraction of CO2 in primary air composition 1
0.0156534,		# mole or mass fraction of H2O in primary air composition 1
0,			# mole or mass fraction of SO2 in primary air composition 1
0,			# mole or mass fraction of H2S in primary air composition 1
0,			# mole or mass fraction of CH4 in primary air composition 1
0,			# mole or mass fraction of Ar in primary air composition 1
0,			# mole or mass fraction of HCl in primary air composition 1
0,			# mole or mass fraction of NO in primary air composition 1
0,			# mole or mass fraction of OH in primary air composition 1
0,			# mole or mass fraction of O in primary air composition 1
0,			# mole or mass fraction of C(S) in secondary air composition
0.206201,		# mole or mass fraction of O2 in secondary air composition
0.777811,		# mole or mass fraction of N2 in secondary air composition
0,			# mole or mass fraction of H2 in secondary air composition
0,			# mole or mass fraction of CO in secondary air composition
0.000334678,		# mole or mass fraction of CO2 in secondary air composition
0.0156534,		# mole or mass fraction of H2O in secondary air composition
0,			# mole or mass fraction of SO2 in secondary air composition
0,			# mole or mass fraction of H2S in secondary air composition
0,			# mole or mass fraction of CH4 in secondary air composition
0,			# mole or mass fraction of Ar in secondary air composition
0,			# mole or mass fraction of HCl in secondary air composition
0,			# mole or mass fraction of NO in secondary air composition
0,			# mole or mass fraction of OH in secondary air composition
0,			# mole or mass fraction of O in secondary air composition
0.41,			# water wall emissivity in zone 1, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 2, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 3, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 4, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 5, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 6, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 7, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 8, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 9, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# water wall emissivity in zone 10, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.7,			# wall emissivity of superheater 1, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.41,			# wall emissivity of roof wall, no need for wall heat transfer resistence in this case since wall temperatures are specified
0.1,			# emissivity of exit plane
700,			# temperature of backside wall beyond exit plane for radiation calculation
1,			# effectiveness factor for gas absorption coefficient
1,			# effectiveness factor for particle absorption coefficient
0.9,			# effectiveness factor for char reaction in zone 1
0.9,			# effectiveness factor for char reaction in zone 2
0.9,			# effectiveness factor for char reaction in zone 3
0.9,			# effectiveness factor for char reaction in zone 4
0.9,			# effectiveness factor for char reaction in zone 5
0.9,			# effectiveness factor for char reaction in zone 6
0.9,			# effectiveness factor for char reaction in zone 7
0.9,			# effectiveness factor for char reaction in zone 8
0.9,			# effectiveness factor for char reaction in zone 9
0.9)			# effectiveness factor for char reaction in zone 10

# varied double inputs are data that may change when operating conditions change
varied_double_inputs = (
86126.3,		# furnace operating pressure (absolute pressure)
338.706,		# primary stream temperature, used for all burner levels in this case
99.0596,		# total primary gas stream mass flow rate, flow rate of each burner level is calculated in this case
50.2856,		# total mass flow rate of solid fuel, flow rate of each burner level is calculated in this case
0.0886,			# mass fraction of moisture in solid fuel
548.706,		# secondary stream temperature
289.644,		# total secondary stream mass flow rate, flow rate of each burner level is calculated in this case
548.706, 		# temperature of OFA level 1, usually OFA temperature is the same as secondary air temperature
121.84,			# mass flow rate of OFA level 1, composition is the same as secondary stream
882.411,		# temperature of vertical water wall in zone 1, usually provided by dynamic water/steam side model
999.745,		# temperature of vertical water wall in zone 2, usually provided by dynamic water/steam side model
1056.58,		# temperature of vertical water wall in zone 3, usually provided by dynamic water/steam side model
1066.05,		# temperature of vertical water wall in zone 4, usually provided by dynamic water/steam side model
1058.3,			# temperature of vertical water wall in zone 5, usually provided by dynamic water/steam side model
978.813,		# temperature of vertical water wall in zone 6, usually provided by dynamic water/steam side model
923.986,		# temperature of vertical water wall in zone 7, usually provided by dynamic water/steam side model
902.376,		# temperature of vertical water wall in zone 8, usually provided by dynamic water/steam side model
773.816,		# temperature of vertical water wall in zone 9, usually provided by dynamic water/steam side model
740,			# temperature of vertical water wall in zone 10, usually provided by dynamic water/steam side model
750,			# wall temperature of superheater 1, usually provided by dynamic water/steam side model
740)			# wall temperature of roof, usually provided by dynamic water/steam side model

# restart inputs are reserved for future use
restart_double_inputs = (0,0)

result = boiler.solve_boiler(integer_inputs, fixed_double_inputs, varied_double_inputs, restart_double_inputs)
#write result to output file
with open("boiler_model_output.txt","w") as outputfile:
	for a in result:
		str = "{0:g}\n".format(a)
		outputfile.write(str)