from __future__ import division, print_function, absolute_import

import six
import logging
import pandas as pd
from IPython.display import display, Markdown
import pyomo.environ as pe
from pyomo.environ import SolverFactory, TransformationFactory
from idaes.core.util.model_serializer import from_json, to_json
import idaes.core.util.model_serializer as model_serial
from idaes.core.util import make_stream_table
import idaes.ui.report as rpt
from idaes.contrib.projects.existing_plants.flowsheets import Plant_01_ph

def main():
    solver_name = "ipopt"
    with open("ipopt.opt", "w") as f:
        f.write("recalc_y yes")
    ipopt_opts = {
        "bound_push":1e-10,
        "acceptable_tol":1e-5,
        "tol":1e-6,
        "linear_solver":"mumps",
        #"max_iter":20,
        #"linear_system_scaling":"mc19",
        #"linear_scaling_on_demand":"no",
        "print_user_options":"yes",
        "dual_inf_tol":1
    }

    petsc_opts = {
        "solver":"petsc",
        "-snes_monitor":"",
        #"-snes_mf":"",
        #"-snes_type":"newtontr",
        "-snes_type":"newtonls",
        "-scale_eqs":1,
        "-scale_vars":0,
        "-snes_rtol":1e-8,
        "-snes_atol":1e-5,
        "-snes_max_it":500,
        #"-pc_factor_mat_solver_type":"strumpack",
        "-pc_factor_mat_solver_type":"mumps",
        #"-pc_type":"ilu",
        "-pc_type":"lu",
        #"-pc_type":"none",
        #"-ksp_type":"gmres",
        "-ksp_type":"preonly",
        #"-start_in_debugger":""
    }

    if solver_name == "ipopt":
        solver = SolverFactory('ipopt')
        opts = ipopt_opts
    elif solver_name == "petsc":
        solver = SolverFactory('petsc')
        opts = petsc_opts

    def solve(bounded=False):
        if not bounded: strip_bounds.apply_to(model, reversible=True)
        res = solver.solve(model, tee=True, symbolic_solver_labels=True, options=opts)
        if not bounded: strip_bounds.revert(model)
        return res

    model=Plant_01_ph(name="Powerplant_Flowsheet", dynamic=False, concrete=True)
    strip_bounds = TransformationFactory('contrib.strip_var_bounds')
    strip_bounds.apply_to(model, reversible=True)
    model.initialize(solver=solver_name, optarg=opts)
    strip_bounds.revert(model)


    for idx, wz in six.iteritems(model.water_wall):
        wz.holdup.heat.unfix()
    model.Q_link.activate()

    res = solve()

    print("Large Residuals")
    for i in rpt.large_residuals(model, tol=1e-7):
        print("{}: {} ".format(i, pe.value(i.lower - i.body())))

    st = make_stream_table(model, attrs=["flow_mol", "pressure", "enth_mol",
        "temperature", "vapor_frac"], t=0)
    with pd.option_context('display.max_rows', None):
        print(st)

    gt = make_stream_table(
        model,
        attrs=["flow_component", "temperature", "pressure"],
        idx={"flow_component":["CO2", "H2O", "N2", "O2", "Ar"]},
        t=0)
    with pd.option_context('display.max_rows', None):
        print(gt)

if __name__ == "__main__":
    main()
