##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
#
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
"""
Example of using the Plant_01 powerplant flowsheet.
"""
__author__ = "John Eslick"

import six
from pyomo.environ import (
    TransformationFactory,
    SolverFactory
)
from idaes.contrib.projects.existing_plants.flowsheets import Plant_01_tpx as Plant_01

def main():
    # Get a transoframtion for removing variable bounds from a model
    strip_bounds = TransformationFactory('contrib.strip_var_bounds')

    # Make the Flowsheet model
    model=Plant_01(name="Powerplant_Flowsheet", dynamic=False, concrete=True)

    # Remove variable bounds, initialize model and put bounds back
    strip_bounds.apply_to(model, reversible=True)
    model.initialize()
    strip_bounds.revert(model)

    # Set up the solver and options
    solver = SolverFactory('ipopt')
    opts = {
        "bound_push":1e-10,
        "acceptable_tol":1e-5,
        "tol":1e-6,
        #"recalc_y":"yes",
        "linear_solver":"mumps",
        #"linear_system_scaling":"mc19",
        #"linear_scaling_on_demand":"no",
        "print_user_options":"yes"}

    # Function to solve the model with strip and restore bounds
    def solve():
        strip_bounds.apply_to(model, reversible=True)
        res = solver.solve(model, tee=True, options=opts)
        strip_bounds.revert(model)

    #Solve model with fixed heat flow in boiler
    solve()

    #Solve model wiht surrogate for boiler heat flow
    for idx, wz in six.iteritems(model.water_wall):
        wz.holdup.heat.unfix()
    model.Q_link.activate()
    solve()

if __name__ == '__main__':
    main()
