##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
from __future__ import division
from __future__ import print_function
from __future__ import absolute_import #disable implicit relative imports

#Pyomo Imports
from pyomo.environ import *
from idaes.contrib.projects.mea_simple.flowsheet.units import HeatExchangeSimple

if __name__ == "__main__":
    """
    A test of this HX model.
    """
    #A test the hx model
    from pyomo.opt import SolverFactory
    opt = SolverFactory('ipopt')

    model = ConcreteModel("Simple HX Test Model")
    model.hx = HeatExchangeSimple(name="hx_test", parent=model)

    #Configuration
    model.hx.A.fix(10.0)
    model.hx.U.fix(100.0)
    model.hx.dP_c.fix(0.0)
    model.hx.dP_h.fix(0.0)

    #Hot Inlet
    model.hx.f_hin.fix(10.0)
    model.hx.P_hin.fix(101325)
    model.hx.T_hin.fix(400)
    model.hx.y_hin['CO2'].fix(0.01)
    model.hx.y_hin['MEA'].fix(0.02)
    model.hx.y_hin['H2O'].fix(0.97)

    #Cold Inlet
    model.hx.f_cin.fix(10.0)
    model.hx.P_cin.fix(101325)
    model.hx.T_cin.fix(300)
    model.hx.y_cin['CO2'].fix(0.01)
    model.hx.y_cin['MEA'].fix(0.02)
    model.hx.y_cin['H2O'].fix(0.97)

    #solve the model
    results = opt.solve(model,tee=True)
    print(results)
    model.display()
