##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
from __future__ import division
from __future__ import print_function
from __future__ import absolute_import #disable implicit relative imports

#Pyomo Imports
from pyomo.environ import *
from idaes.contrib.projects.mea_simple.flowsheet.units import Reboiler

if __name__ == "__main__":
    """
    A test of this HX model.
    """
    #A test the hx model
    from pyomo.opt import SolverFactory
    opt = SolverFactory('ipopt')

    model = ConcreteModel("Simple Reboiler Test Model")
    model.hx = Reboiler(name="hx_test", parent=model)

    #Configuration
    model.hx.A.fix(10.0)
    model.hx.U.fix(100.0)

    #Solvent inlet
    model.hx.f_in.fix(10.0)
    model.hx.P_in.fix(108000)
    model.hx.T_in.fix(360)
    model.hx.y_in['CO2'].fix(0.04)
    model.hx.y_in['MEA'].fix(0.05)
    model.hx.y_in['H2O'].fix(0.91)

    model.hx.P_lout.fix(108000)
    model.hx.vf.fix(0.4)

    #solve the model
    results = opt.solve(model,tee=True)
    print(results)
    model.display()
