##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
#
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
"""
Plugin import tests
"""
import unittest
import subprocess
import os
import sys
from pyomo.environ import TransformationFactory

class TestPluginImport(unittest.TestCase):
    def test_pyosyn_plugin(self):
        """Test that the pyosyn plugin can be loaded"""
        # importing anything from idaes should cause plugins to be loaded
        # so the test is run in a subprocess to be sure that nothing has
        # been imported before testing.
        #
        # The test script produces two lines indicating if two tests succeed
        # 1) Before importing idaes,
        #    TransformationFactory("idea.conceptual_design") is None
        # 2) After importing idaes,
        #    TransformationFactory("idea.conceptual_design") is a Pyosyn object
        test = "\n".join((
            'from __future__ import division, print_function, absolute_import',
            'from pyomo.environ import TransformationFactory as TF',
            'x = TF("idaes.conceptual_design") is None',
            'import idaes',
            'y = "Pyosyn" in str(type(TF("idaes.conceptual_design")))',
            'print("=Test Result=>{}:{}<=Test Result=".format(x,y))'))

        s = "=Test Result=>{}:{}<=Test Result=".format(True, True)
        s = s.encode()
        assert(s in subprocess.check_output([sys.executable, "-c", test]))
