"""
Tests for PropertyMetadata and related functionality in `property_base` module.
"""
__author__ = 'Dan Gunter <dkgunter@lbl.gov>'

# third-party
import pytest
# package
from idaes.core import property_base as pb


def test_property_info_class():
    args = []
    pytest.raises(TypeError, pb.PropertyMetadata, *args)
    args = ['foo', 'bar', 'baz']
    for i in range(1, 4):
        pb.PropertyMetadata(*args[:i])


# Used for test_get_metadata
class DummyParam(pb.PropertyParameterBase):
    _name, _method, _units = ('foo', 'bar', 'baz')
    _N = 5

    def get_supported_properties(self):
        return {self._name + i: {'method': self._method + i,
                                 'units': self._units + i}
                for i in map(str, range(self._N))}


class BlockMock(object):
    _block_data_config = {}


def test_get_metadata():
    DP = DummyParam  # alias
    infod = DP.get_metadata().properties
    for i in map(str, range(DP._N)):
        key = DP._name + i
        assert key in infod
        info = infod[key]
        assert info['name'] == key
        assert info['method'] == DP._method + i
        assert info['units'] == DP._units + i


def test_get_metadata_null():
    null = pb.PropertyParameterBase
    meta = null.get_metadata()
    assert meta.properties == {}
    assert meta.default_units == {}


class BadSanta(pb.PropertyParameterBase):
    def __init__(self, *args):
        super(BadSanta, self).__init__(*args)
        self.infinity_war = 1 / 0  # raises ZeroDivisionError


def test_constructor_fails():
    pytest.raises(ZeroDivisionError, BadSanta.get_metadata)


def test_property_class_metadata():
    pcm = pb.PropertyClassMetadata()
    assert pcm.default_units == {}
    assert pcm.properties == {}
    pcm.add_property_metadata(pb.PropertyMetadata('foo',
                                                  method='bar',
                                                  units='baz'))
    assert 'foo' in pcm.properties
    foo = pcm.properties['foo']
    assert foo['name'] == 'foo'
    assert foo['method'] == 'bar'
    assert foo['units'] == 'baz'
    pcm.default_units = {'time': 'fortnights'}
