##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
"""
Test Stream Table
"""
from __future__ import division, print_function, absolute_import

import pytest
from .test_stream import Flowsheet, Unit, PropertyParameterBlock, \
                         PropertyBlock, m

from idaes.core.util import make_stream_table
from idaes.core import Stream

def test_table1(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b"],
        idx={},
        t=0,
        ignore_missing=False)
    assert(len(table) == 1)
    assert(table["a"]["fs.stream"] == 1.0)
    assert(table["b"]["fs.stream"] == 2.0)

def test_table2(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "x"],
        idx={},
        t=0,
        ignore_missing=True)
    assert(len(table) == 1)
    assert(table["a"]["fs.stream"] == 1.0)
    assert(table["b"]["fs.stream"] == 2.0)

def test_table3(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "x"],
        idx={},
        t=0,
        ignore_missing=False)
    assert(len(table) == 0)

def test_table3(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "c"],
        idx={"c":["comp1", "comp2"]},
        t=0,
        ignore_missing=False)
    print(table)
    m.fs.u1.outlet[0].vars["c"].display()
    assert(len(table) == 1)
    assert(table["a"]["fs.stream"] == 1.0)
    assert(table["b"]["fs.stream"] == 2.0)
    assert(table["c[comp1]"]["fs.stream"] == 3.0)
    assert(table["c[comp2]"]["fs.stream"] == 3.0)

def test_table4(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "c"],
        idx={"c":["comp1", "comp2", "x"]},
        t=0,
        ignore_missing=False)
    print(table)
    m.fs.u1.outlet[0].vars["c"].display()
    assert(len(table) == 0)

def test_table5(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "c"],
        idx={"c":["comp1", "comp2", "x"]},
        t=0,
        ignore_missing=True)
    print(table)
    m.fs.u1.outlet[0].vars["c"].display()
    assert(len(table) == 1)
    assert(table["a"]["fs.stream"] == 1.0)
    assert(table["b"]["fs.stream"] == 2.0)
    assert(table["c[comp1]"]["fs.stream"] == 3.0)
    assert(table["c[comp2]"]["fs.stream"] == 3.0)

def test_table6(m):
    m.fs.stream = Stream(source=m.fs.u1.outlet,
                         destination=m.fs.u2.inlet)
    table = make_stream_table(
        model=m,
        attrs=["a", "b", "c"],
        idx={"a":None, "b":None, "c":["comp1", "comp2"]},
        t=0,
        ignore_missing=False)
    print(table)
    m.fs.u1.outlet[0].vars["c"].display()
    assert(len(table) == 1)
    assert(table["a"]["fs.stream"] == 1.0)
    assert(table["b"]["fs.stream"] == 2.0)
    assert(table["c[comp1]"]["fs.stream"] == 3.0)
    assert(table["c[comp2]"]["fs.stream"] == 3.0)
